#ifndef __SYMM_GROUPS__
#define __SYMM_GROUPS__

#include <vector>
#include <utility>

typedef std::vector<std::vector<std::pair<int, int> > > symmGroups;

#endif
